#include <stdlib.mqh>
#include <stderror.mqh>
#include <JA_Money_Management.mq4>
#include <JA_Order_Information.mq4>


extern int timeframe = 15;
extern double equity_to_risk = 0.02;
extern double barDelay = 5;
extern int ATR_period = 14;
extern double ATR_stop_loss_multiplier = 1;
extern double ATR_take_profit_multiplier = 0.5;
extern int maximum_spread = 2;


int currentOrder;
datetime lastTradeTime = 0;


int init()
{
   return(0);
}


int deinit()
{
   return(0);
}


int start()
{
   //get the current order
   currentOrder = getOrder(Symbol());
      
   if(currentOrder == -1 &&  MarketInfo(Symbol(), MODE_SPREAD) <= maximum_spread){
      if(possibleOpenPosition() == "LONG"){
         openPosition(OP_BUY);
      }else if(possibleOpenPosition() == "SHORT"){
         openPosition(OP_SELL);
      }
   }
           
   //show comment
   Comment(createComment());

   return(0);
}


string possibleOpenPosition()
{  
   int lastTradeBar = iBarShift(Symbol(), timeframe, lastTradeTime);
   
   double Trend_Envelopes_Up_Envelope = iCustom(Symbol(), timeframe, "TrendEnvelopes_v1", 0, 0);
   double Trend_Envelopes_Down_Envelope = iCustom(Symbol(), timeframe, "TrendEnvelopes_v1", 1, 0);
   double Trend_Envelopes_Up_Arrow = iCustom(Symbol(), timeframe, "TrendEnvelopes_v1", 2, 0);
   double Trend_Envelopes_Down_Arrow = iCustom(Symbol(), timeframe, "TrendEnvelopes_v1", 3, 0);
   
   double Volatility[2];
   Volatility[0] = iCustom(Symbol(), timeframe, "DM_Volatility", 0, 0);
   Volatility[1] = iCustom(Symbol(), timeframe, "DM_Volatility", 0, 1);
   double Volatility_Level = 6 * Point;

   double highestPrice = iHigh(Symbol(), timeframe, iHighest(Symbol(), timeframe, MODE_HIGH, 25, 0));
   double lowestPrice = iLow(Symbol(), timeframe, iLowest(Symbol(), timeframe, MODE_LOW, 25, 0));
   double highLowDifference = (highestPrice - lowestPrice) / Point;

   if(
      Trend_Envelopes_Up_Arrow == EMPTY_VALUE
      && Trend_Envelopes_Down_Arrow != EMPTY_VALUE
      && Trend_Envelopes_Up_Envelope == EMPTY_VALUE
      && Trend_Envelopes_Down_Envelope != EMPTY_VALUE
      && highLowDifference < 50
      && lastTradeTime != iTime(Symbol(), timeframe, 0)
      && Volatility[0] > Volatility[1]
      ){
      return("LONG");
   }else if(
      Trend_Envelopes_Up_Arrow != EMPTY_VALUE
      && Trend_Envelopes_Down_Arrow == EMPTY_VALUE
      && Trend_Envelopes_Up_Envelope != EMPTY_VALUE
      && Trend_Envelopes_Down_Envelope == EMPTY_VALUE
      && highLowDifference < 50
      && lastTradeTime != iTime(Symbol(), timeframe, 0)
      && Volatility[0] > Volatility[1]
      ){
      return("SHORT");
   }
   return("NO_TRADE");
}


void openPosition(int tradeType)
{
   double openPrice;
   double stopLoss;
   double takeProfit;
   double lots;
   color orderColor;
   double ATR = iATR(Symbol(), timeframe, ATR_period, 0);
     
   if(tradeType == OP_BUY){
      openPrice = Ask;
      stopLoss = openPrice - (ATR * ATR_stop_loss_multiplier);
      takeProfit = openPrice + (ATR * ATR_take_profit_multiplier);
      lots = calcPositionSize(equity_to_risk * AccountFreeMargin(), (ATR * ATR_stop_loss_multiplier) / Point, Symbol(), "USD", MarketInfo(Symbol(), MODE_MINLOT), MarketInfo(Symbol(), MODE_MAXLOT));
      orderColor = Blue;
   }else if(tradeType == OP_SELL){
      openPrice = Bid;
      stopLoss = openPrice + (ATR * ATR_stop_loss_multiplier);
      takeProfit = openPrice - (ATR * ATR_take_profit_multiplier);
      lots = calcPositionSize(equity_to_risk * AccountFreeMargin(), (ATR * ATR_stop_loss_multiplier) / Point, Symbol(), "USD", MarketInfo(Symbol(), MODE_MINLOT), MarketInfo(Symbol(), MODE_MAXLOT));
      orderColor = Red;
   }
   OrderSend(Symbol(), tradeType, lots, openPrice, 3, stopLoss, takeProfit, "", 0, 0, orderColor);
   lastTradeTime = iTime(Symbol(), timeframe, 0);
}


string createComment()
{
   OrderSelect(0,SELECT_BY_POS,MODE_HISTORY);
   string comment = StringConcatenate(
      "\n",
      "Last Error: ",ErrorDescription(GetLastError())
   );
   return(comment);
}

